@@ -10,7 +10,7 @@ from warpseq.api.interfaces.base import CollectionApi
 class Scenes(CollectionApi):
 
     object_class    = Scene
-    public_fields   = [ 'name', 'scale', 'auto_advance' ]
+    public_fields   = [ 'name', 'scale', 'auto_advance', 'rate' ]
     song_collection = 'scenes'
     add_method      = 'add_scenes'
     add_required    = [ ]
