@@ -4,6 +4,8 @@
 # Apache2 Licensed
 # ------------------------------------------------------------------
 
+import json
+
 class SongApi(object):
 
     def __init__(self, public_api, song):
@@ -16,3 +18,9 @@ class SongApi(object):
         if scale:
             scale = self.public_api.scales.lookup(scale, require=True)
             self.song.scale = scale
+
+    def to_dict(self):
+        return self.song.to_dict()
+
+    def to_json(self):
+        return json.dumps(self.to_dict(), sort_keys=True, indent=4)
\ No newline at end of file
