@@ -18,7 +18,7 @@ class Transforms(CollectionApi):
     remove_method    = 'remove_transform'
     nullable_edits   = [ ]
 
-    def add(self, name, slots:list=None, divide:int=1, applies_to:str=None, direction='forward', auto_reset=False):
+    def add(self, name, slots:list=None, divide:int=None, applies_to:str='both', direction='forward', auto_reset=False):
         params = locals()
         return self._generic_add(name, params)
 
