@@ -9,6 +9,7 @@
 
 import gc
 import random
+import json
 
 from warpseq.api.interfaces.devices import Devices
 from warpseq.api.interfaces.instruments import Instruments
@@ -30,6 +31,10 @@ MIDI_PORTS = midi.get_devices()
 
 class Api(object):
 
+    __slots__ = ( '_filename', '_song', 'song', 'devices', 'instruments', 'scales',
+                  'patterns', 'data_pools', 'transforms', 'scenes', 'tracks', 'clips',
+                  'player', 'song', '_callbacks' )
+
     def __init__(self, default_callbacks=True):
         self._reset()
         self._callbacks = Callbacks()
@@ -47,7 +52,9 @@ class Api(object):
 
         self._filename = None
         self._song = Song(name='')
+        self._setup_api()
 
+    def _setup_api(self):
         self.song = SongApi(self, self._song)
         self.devices = Devices(self, self._song)
         self.instruments = Instruments(self, self._song)
@@ -65,14 +72,25 @@ class Api(object):
     # ------------------------------------------------------------------------------------------------------------------
     # FIXME: song save/load work in progress
 
-    def load(self, filename:str):
+    def from_dict(self, data):
+        self._song = Song.from_dict(data)
+        self._setup_api()
 
+    def to_dict(self):
+        return self._song.to_dict()
+
+    def from_json(self,  data):
+        data = json.loads(data)
+        return self.from_dict(data)
+
+    def to_json(self):
+        return self._song.to_json()
+
+    def load(self, filename:str):
         fh = open(filename, "r")
         data = fh.read()
         fh.close()
-        self._song = Song.from_json(data)
-        self._filename = filename
-        self._setup_api()
+        self.from_json(data)
 
     def save(self):
         if not self._filename:
