@@ -13,6 +13,7 @@ from .base import NewReferenceObject
 from .scale import Scale
 from warpseq.model.context import Context
 from warpseq.model.event import Event, NOTE_ON
+from warpseq.model.chord import Chord
 
 # FAIR WARNING: some refactoring still pending
 
@@ -178,6 +179,12 @@ class Clip(NewReferenceObject):
         # processing tie events along the way and also delay metadata
 
         events = []
+        new_chords = []
+
+        # FIXME: this should be modified to keep the subsystem as chords the whole time
+        # through the first part
+
+        # FIXME: move first part into function
 
         for slot in chords:
 
@@ -188,6 +195,8 @@ class Clip(NewReferenceObject):
 
                 tie_bonus = slot.tie_count()
 
+                new_chord = []
+
                 for note in slot.notes:
 
                     if note is not None and not note.tie and not note.muted:
@@ -204,21 +213,40 @@ class Clip(NewReferenceObject):
                         if not note.repeat:
                             note.length = note.length + tie_bonus
                             note.end_time = note.end_time + tie_bonus
-                            event1 = Event(type=NOTE_ON, note=note,time=int(note.start_time))
-                            events.append(event1)
-                        else:
-                            delta = (note.end_time - note.start_time) / (note.repeat + 1)
-                            for x in range(0, note.repeat):
-                                n1 = note.copy()
-                                n1.length = delta
-                                n1.start_time = note.start_time + (x*delta)
-                                n1.end_time = n1.start_time + delta
-                                if x == note.repeat:
-                                    n1.length = n1.length + tie_bonus
-                                    n1.end_time = n1.end_time + tie_bonus
-                                event2 = Event(type=NOTE_ON, note=n1, time=int(n1.start_time))
-                                events.append(event2)
 
+                        new_chord.append(note)
+
+                new_chords.append(Chord(notes=new_chord))
+
+        for chord in new_chords:
+
+            if not chord.notes[0].repeat:
+
+                event1 = Event(type=NOTE_ON, note=chord,time=int(chord.notes[0].start_time))
+                events.append(event1)
+
+            else:
+
+                chord_notes = []
+
+                delta = (note.end_time - note.start_time) / (note.repeat + 1)
+
+                for x in range(0, note.repeat):
+
+                    n1 = note.copy()
+                    n1.length = delta
+                    n1.start_time = note.start_time + (x*delta)
+                    n1.end_time = n1.start_time + delta
+
+                    if x == note.repeat:
+                        n1.length = n1.length + tie_bonus
+                        n1.end_time = n1.end_time + tie_bonus
+
+
+                    chord_notes.append(n1)
+
+                event2 = Event(type=NOTE_ON, note=Chord(notes=chord_notes), time=int(n1.start_time))
+                events.append(event2)
 
         return events
 
