@@ -8,19 +8,12 @@
 
 from .base import NewReferenceObject
 from warpseq.playback.midi import open_port
-from warpseq.utils.serialization import Serializer
 
 class Device(NewReferenceObject):
 
-    __slots__ = [ 'name', 'obj_id', '_midi_out' ]
+    __slots__ = [ 'name', 'obj_id', '_midi_out', ]
 
-    SERIALIZER = Serializer(
-        values = ( 'name', ),
-        objects = (),
-        object_lists = (),
-        objects_2d = (),
-        custom=(),
-    )
+    SAVE_AS_REFERENCES = []
 
     def __init__(self, name=None, obj_id=None):
         self.name = name
