@@ -9,20 +9,12 @@
 
 from .base import NewReferenceObject
 import functools
-from warpseq.utils.serialization import Serializer
 
 class Instrument(NewReferenceObject):
 
     __slots__ = [ 'name', 'channel', 'device', 'min_octave', 'base_octave', 'max_octave', 'default_velocity', 'muted' ]
 
-
-    SERIALIZER = Serializer(
-        values = ( 'name', 'channel', 'min_octave', 'base_octave', 'max_octave', 'default_velocity', 'muted' ),
-        objects = ( 'device', ),
-        object_lists = (),
-        objects_2d = (),
-        custom=()
-    )
+    SAVE_AS_REFERENCES = [ 'device' ]
 
     def __init__(self, name=None, channel=None, device=None, min_octave=0, base_octave=3, max_octave=10,
                  default_velocity=120, muted=False, obj_id=None):
