@@ -10,13 +10,19 @@
 from .base import NewReferenceObject
 from .instrument import Instrument
 
+ALL_INSTRUMENTS = 'all_instruments'
+ROTATE = 'rotate'
+ROTATE_CHORDS = 'rotate_chords'
+SPREAD = 'spread'
+INSTRUMENT_MODE_CHOICES = [ ALL_INSTRUMENTS, ROTATE, ROTATE_CHORDS, SPREAD ]
+
 class Track(NewReferenceObject):
 
-    __slots__ = [ 'name', 'muted', 'instrument', 'instruments', 'clip_ids', 'obj_id' ]
+    __slots__ = [ 'name', 'muted', 'instrument', 'instruments', 'clip_ids', 'obj_id', 'instrument_mode' ]
 
     SAVE_AS_REFERENCES = [ 'instruments', 'instrument' ]
 
-    def __init__(self, name=None, muted=False, instrument=None, instruments=None, clip_ids=None, obj_id=None):
+    def __init__(self, name=None, muted=False, instrument=None, instruments=None, instrument_mode=ALL_INSTRUMENTS, clip_ids=None, obj_id=None):
 
         self.name = name
         self.muted = muted
@@ -27,6 +33,14 @@ class Track(NewReferenceObject):
         self.instruments = instruments
         self.instrument = instrument
 
+
+        if instrument_mode is None:
+            instrument_mode = ALL_INSTRUMENTS
+
+        self.instrument_mode = instrument_mode
+
+        assert instrument_mode in INSTRUMENT_MODE_CHOICES
+
         if clip_ids is None:
             clip_ids = []
         self.clip_ids = clip_ids
