@@ -94,6 +94,9 @@ class Transform(NewReferenceObject, Directionable):
         results = []
         context = Context(song=song, pattern=pattern, scale=scale, track=track, base_length=slot_duration)
 
+        if self.auto_reset:
+            self.reset()
+
         for chord in chord_list:
 
             if chord is None:
