@@ -14,7 +14,10 @@ from warpseq.api.exceptions import *
 from warpseq.model.registers import register_playing_note, unregister_playing_note
 from warpseq.playback.midi import midi_note_on, midi_note_off, midi_cc
 from warpseq.model.chord import Chord
+from warpseq.model.note import Note
 from warpseq.model.event import Event, NOTE_OFF, NOTE_ON
+from warpseq.model.track import ALL_INSTRUMENTS, ROTATE, SPREAD, ROTATE_CHORDS
+from warpseq.utils import utils
 
 def _get_note_number(note, instrument):
 
@@ -39,7 +42,8 @@ def _get_note_number(note, instrument):
 
 class RealtimeEngine(object):
 
-    __slots__ = ['song','track','clip','midi_out','midi_port','mod_expressions','callbacks','on_count','player']
+    __slots__ = ['song','track','clip','midi_out','midi_port','mod_expressions','callbacks','on_count','player',
+                 '_all_instruments', '_instruments_roller', '_hocket_roller', '_poly_roller']
 
     def __init__(self, song=None, track=None, clip=None, player=None):
         self.song = song
@@ -48,6 +52,11 @@ class RealtimeEngine(object):
         self.player = player
         self.callbacks = Callbacks()
 
+        self._all_instruments = self.track.get_instruments_to_play()
+        self._hocket_roller = utils.roller(self._all_instruments)
+        # self._poly_roller = utils.roller(self._all_instruments)
+
+
     def play(self, event):
 
         # deferred events happen when there are intra-track events such as replacing the note
@@ -56,9 +65,6 @@ class RealtimeEngine(object):
         # because the mod expression does throw away the note value and capture the value from
         # the guide track...
 
-        if event.note.muted:
-            return
-
         if event.type == NOTE_ON:
 
             # we have to process deferred expressions twice because of the mod events
@@ -75,15 +81,40 @@ class RealtimeEngine(object):
         # it is possible for mod expressions to take notes and return Chords. We have to do
         # cleanup here to turn this back into a list of notes.
 
-        if type(event.note) == Chord:
-            for x in event.note.notes:
-                evt = event.copy()
-                evt.note = x
-                evt.note.deferred = False
-                self.play(evt)
+        if not event.note:
             return
 
-        if not event.note:
+        if type(event.note) == Chord:
+
+
+            mode = self.track.instrument_mode
+
+            chosen = None
+            if mode == SPREAD:
+                self._hocket_roller = utils.roller(self._all_instruments)
+            if mode == ROTATE:
+                chosen = next(self._hocket_roller)
+
+            for (i,x) in enumerate(event.note.notes):
+
+                if x.muted:
+                    return
+
+                evt = event.copy()
+                evt.note = x
+                #evt.note.deferred = False
+
+                if mode == ALL_INSTRUMENTS:
+                    evt.instruments = self._all_instruments
+                elif mode in [ ROTATE_CHORDS, SPREAD ]:
+                    evt.instruments = [ next(self._hocket_roller) ]
+                elif mode == ROTATE:
+                    evt.instruments = [ chosen ]
+                else:
+                    raise Exception("unknown mode")
+
+                self.play(evt)
+
             return
 
         if event.type == NOTE_ON:
@@ -98,13 +129,15 @@ class RealtimeEngine(object):
 
             for (control, value) in event.note.ccs.items():
                 control = int(control)
-                for instrument in self.track.get_instruments_to_play():
+                for instrument in event.get_instruments():
                     midi_cc(instrument.get_midi_out(), instrument.channel, control, int(value))
 
 
             if not (self.track.muted or event.note.muted):
+
                 self.player.inject_off_event(event)
-                for instrument in self.track.get_instruments_to_play():
+
+                for instrument in event.get_instruments():
                     if not instrument.muted:
                         #print("PLAY ON %s: %s" % (self.track.name, event.note))
                         midi_note_on(instrument.get_midi_out(), instrument.channel, _get_note_number(event.note, instrument), velocity)
@@ -130,7 +163,8 @@ class RealtimeEngine(object):
 
             if self.track.muted:
                 return
-            for instrument in self.track.get_instruments_to_play():
+
+            for instrument in event.get_instruments():
                 if not instrument.muted:
                     midi_note_off(instrument.get_midi_out(), instrument.channel,  _get_note_number(event.note, instrument), velocity)
 
